@@ -3,6 +3,7 @@ mod use_before_unload;
 mod use_counter;
 mod use_effect_once;
 mod use_event;
+mod use_geolocation;
 mod use_hash;
 mod use_interval;
 mod use_is_first_mount;
@@ -39,6 +40,7 @@ pub use use_before_unload::*;
 pub use use_counter::*;
 pub use use_effect_once::*;
 pub use use_event::*;
+pub use use_geolocation::*;
 pub use use_hash::*;
 pub use use_interval::*;
 pub use use_is_first_mount::*;
